@@ -25,19 +25,18 @@ SidebarPreviewBaseEntry::SidebarPreviewBaseEntry(SidebarPreviewBase* sidebar, co
 
     g_signal_connect(this->widget, "draw", G_CALLBACK(drawCallback), this);
 
-    g_signal_connect(this->widget, "clicked", G_CALLBACK(+[](GtkWidget* widget, SidebarPreviewBaseEntry* self) {
-                         self->mouseButtonPressCallback();
-                         return true;
+    g_signal_connect(GTK_BUTTON(this->widget), "clicked", G_CALLBACK(+[](GtkButton*, gpointer self) {
+                         static_cast<SidebarPreviewBaseEntry*>(self)->mouseButtonPressCallback();
                      }),
                      this);
 
-    const auto clickCallback = G_CALLBACK(+[](GtkWidget* widget, GdkEvent* event, SidebarPreviewBaseEntry* self) {
+    const auto clickCallback = G_CALLBACK(+[](GtkWidget*, GdkEvent* event, gpointer self) {
         // Open context menu on right mouse click
         if (event->type == GDK_BUTTON_PRESS) {
             auto mouseEvent = reinterpret_cast<GdkEventButton*>(event);
             if (mouseEvent->button == 3) {
-                self->mouseButtonPressCallback();
-                self->sidebar->openPreviewContextMenu();
+                static_cast<SidebarPreviewBaseEntry*>(self)->mouseButtonPressCallback();
+                static_cast<SidebarPreviewBaseEntry*>(self)->sidebar->openPreviewContextMenu();
                 return true;
             }
         }
