@@ -1,6 +1,7 @@
 #include "Document.h"
 
 #include <array>
+#include <codecvt>  // for codecvt_utf8_utf16
 #include <ctime>    // for size_t, localtime, strf...
 #include <iomanip>
 #include <sstream>
@@ -63,7 +64,7 @@ void Document::lock() {
 
     //	if(tryLock()) {
     //		fprintf(stderr, "Locked by\n");
-    //		Stacktrace::printStracktrace();
+    //		Stacktrace::printStacktrace();
     //		fprintf(stderr, "\n\n\n\n");
     //	} else {
     //		g_mutex_lock(&this->documentLock);
@@ -74,7 +75,7 @@ void Document::unlock() {
     this->documentLock.unlock();
 
     //	fprintf(stderr, "Unlocked by\n");
-    //	Stacktrace::printStracktrace();
+    //	Stacktrace::printStacktrace();
     //	fprintf(stderr, "\n\n\n\n");
 }
 
@@ -133,8 +134,9 @@ auto Document::createSaveFolder(fs::path lastSavePath) -> fs::path {
     return lastSavePath;
 }
 
-auto Document::createSaveFilename(DocumentType type, const std::string& defaultSaveName, const std::string& defaultPdfName) -> fs::path {
-    constexpr static std::string_view forbiddenChars = {"\\/:*?\"<>|"};
+auto Document::createSaveFilename(DocumentType type, const std::string& defaultSaveName,
+                                  const std::string& defaultPdfName) -> fs::path {
+    constexpr static std::wstring_view forbiddenChars = {L"\\/:*?\"<>|"};
     std::string wildcardString;
     if (type != Document::PDF) {
         if (!filepath.empty()) {
@@ -154,13 +156,15 @@ auto Document::createSaveFilename(DocumentType type, const std::string& defaultS
         wildcardString = SaveNameUtils::parseFilenameFromWildcardString(defaultPdfName, this->filepath.filename());
     }
 
-    const char* format = wildcardString.empty() ? defaultSaveName.c_str() : wildcardString.c_str();
+    auto format_str = wildcardString.empty() ? defaultSaveName : wildcardString;
+
+    std::wstring_convert<std::codecvt_utf8<wchar_t>> converter;
+    auto format = converter.from_bytes(format_str);
 
     // Todo (cpp20): use <format>
-    std::ostringstream ss;
-    ss.imbue(std::locale());
+    std::wostringstream ss;
     time_t curtime = time(nullptr);
-    ss << std::put_time(localtime(&curtime), format);
+    ss << std::put_time(localtime(&curtime), format.c_str());
     auto filename = ss.str();
     // Todo (cpp20): use <ranges>
     for (auto& c: filename) {
@@ -168,7 +172,10 @@ auto Document::createSaveFilename(DocumentType type, const std::string& defaultS
             c = '_';
         }
     }
-    fs::path p = filename;
+
+    auto fn2 = converter.to_bytes(filename);
+    auto p = fs::u8path(fn2);
+
     Util::clearExtensions(p);
     return p;
 }
@@ -304,6 +311,11 @@ void Document::updateIndexPageNumbers() {
     }
 }
 
+void Document::setPdfAttributes(const fs::path& filename, bool attachToDocument) {
+    this->pdfFilepath = filename;
+    this->attachPdf = attachToDocument;
+}
+
 auto Document::readPdf(const fs::path& filename, bool initPages, bool attachToDocument, gpointer data, gsize length)
         -> bool {
     GError* popplerError = nullptr;
@@ -359,6 +371,8 @@ auto Document::readPdf(const fs::path& filename, bool initPages, bool attachToDo
     return true;
 }
 
+void Document::resetPdf() { pdfDocument.reset(); }
+
 void Document::setPageSize(PageRef p, double width, double height) { p->setSize(width, height); }
 
 auto Document::getPageWidth(PageRef p) -> double { return p->getWidth(); }
