@@ -20,6 +20,7 @@
 #include "control/xojfile/SaveHandler.h"
 #include "model/Image.h"
 #include "model/Stroke.h"
+#include "model/TexImage.h"
 #include "model/Text.h"
 #include "model/XojPage.h"
 #include "util/PathUtil.h"
@@ -424,32 +425,45 @@ TEST(ControlLoadHandler, imageSaveJpegBackwardCompat) {
     checkImageFormat(img, "png");
 }
 
+TEST(ControlLoadHandler, linebreaksLatex) {
+    // FIXME: use a path in CMAKE_BINARY_DIR or CMAKE_CURRENT_BINARY_DIR
+    const fs::path outPath =
+            fs::temp_directory_path() / "xournalpp-test-units_ControlLoaderHandler_linebreaksLatex.xopp";
+
+    // save journal containing latex object with linebreaks.
+    {
+        LoadHandler handler;
+        auto doc = handler.loadDocument(GET_TESTFILE("load/linebreaksLatex.xopp"));
+        ASSERT_TRUE(doc) << "latex objects with linebreaks";
+
+        SaveHandler saver;
+        saver.prepareSave(doc);
+        saver.saveTo(outPath);
+    }
+
+    // check that the saved latex objects have correct linebreaks.
+    LoadHandler handler;
+    auto doc = handler.loadDocument(outPath);
+    ASSERT_TRUE(doc) << "saved latex objects should have correct linebreaks";
+    ASSERT_EQ(1U, doc->getPageCount());
+    PageRef page = doc->getPage(0);
+    ASSERT_EQ(1U, page->getLayerCount());
+    Layer* layer = (*page->getLayers())[0];
+
+    TexImage* teximage = (TexImage*)layer->getElements()[0];
+    EXPECT_EQ("{.\n}", teximage->getText());
+
+    teximage = (TexImage*)layer->getElements()[1];
+    EXPECT_EQ("{.\r}", teximage->getText());
+
+    teximage = (TexImage*)layer->getElements()[2];
+    EXPECT_EQ("{.\r\n}", teximage->getText());
+}
+
 TEST(ControlLoadHandler, testLoadStoreLoadDefault) {
     testLoadStoreLoadHelper(GET_TESTFILE("packaged_xopp/suite.xopp"), /*tol=*/1e-8);
 }
 
-
-#ifdef __linux__
-TEST(ControlLoadHandler, testLoadStoreLoadGerman) {
-    constexpr auto testLocale = "de_DE.UTF-8";
-    char* currentLocale = setlocale(LC_ALL, testLocale);
-    if (currentLocale == nullptr) {
-        auto environ = g_get_environ();
-        bool isCI = g_environ_getenv(environ, "CI");
-        g_strfreev(environ);
-        if (isCI) {
-            EXPECT_TRUE(false);
-        } else {
-            std::cout << "Skipping testLoadStoreLoadGerman! Consider generating the 'de_DE.UTF-8' locale on your "
-                         "system."
-                      << std::endl;
-        }
-    }
-    testLoadStoreLoadHelper(GET_TESTFILE("packaged_xopp/suite.xopp"), /*tol=*/1e-8);
-    setlocale(LC_ALL, "C");
-}
-#endif
-
 // Backwards compatibility test that checks that full-precision float strings can be loaded.
 // See https://github.com/xournalpp/xournalpp/pull/4065
 TEST(ControlLoadHandler, testLoadStoreLoadFloatBwCompat) {
@@ -509,3 +523,32 @@ TEST(ControlLoadHandler, testStrokeWidthRecovery) {
 
     testPressureValues(8, {0.25, 0.30, 0.40, Point::NO_PRESSURE});
 }
+
+TEST(ControlLoadHandler, testLoadStoreCJK) {
+    LoadHandler handler;
+    auto filepath = string(GET_TESTFILE("cjk/测试.xopp"));
+    Document* doc = handler.loadDocument(fs::u8path(filepath));
+    ASSERT_NE(doc, nullptr);
+
+    EXPECT_STREQ(doc->getPdfFilepath().filename().u8string().c_str(), u8"测试.pdf");
+
+    EXPECT_EQ((size_t)2, doc->getPageCount());
+    const auto page = doc->getPage(0);
+
+    EXPECT_EQ((size_t)1, page->getLayerCount());
+    const auto* layer = (*page->getLayers())[0];
+
+    const auto& elements = layer->getElements();
+    ASSERT_EQ((size_t)3, layer->getElements().size());
+
+    auto check_element = [&](int i, const char* answer) {
+        EXPECT_EQ(ELEMENT_TEXT, elements[i]->getType());
+        auto* text = dynamic_cast<Text*>(elements[i]);
+        ASSERT_NE(text, nullptr);
+        EXPECT_STREQ(text->getText().c_str(), answer);
+    };
+
+    check_element(0, u8"Test");
+    check_element(1, u8"测试");
+    check_element(2, u8"テスト");
+}
